package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.ScheduleTask;

/**
 * 任务定时执行Mapper接口
 * 
 * @author ruoyi
 * @date 2024-07-24
 */
public interface ScheduleTaskMapper 
{
    /**
     * 查询任务定时执行
     * 
     * @param id 任务定时执行主键
     * @return 任务定时执行
     */
    public ScheduleTask selectScheduleTaskById(Long id);

    /**
     * 查询任务定时执行列表
     * 
     * @param scheduleTask 任务定时执行
     * @return 任务定时执行集合
     */
    public List<ScheduleTask> selectScheduleTaskList(ScheduleTask scheduleTask);

    /**
     * 新增任务定时执行
     * 
     * @param scheduleTask 任务定时执行
     * @return 结果
     */
    public int insertScheduleTask(ScheduleTask scheduleTask);

    /**
     * 修改任务定时执行
     * 
     * @param scheduleTask 任务定时执行
     * @return 结果
     */
    public int updateScheduleTask(ScheduleTask scheduleTask);

    /**
     * 删除任务定时执行
     * 
     * @param id 任务定时执行主键
     * @return 结果
     */
    public int deleteScheduleTaskById(Long id);

    /**
     * 批量删除任务定时执行
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteScheduleTaskByIds(Long[] ids);
}
