package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.ScheduleTask;
import com.ruoyi.system.service.IScheduleTaskService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 任务定时执行Controller
 * 
 * @author ruoyi
 * @date 2024-07-24
 */
@RestController
@RequestMapping("/system/task")
public class ScheduleTaskController extends BaseController
{
    @Autowired
    private IScheduleTaskService scheduleTaskService;

    /**
     * 查询任务定时执行列表
     */
    // @PreAuthorize("@ss.hasPermi('system:task:list')")
    @GetMapping("/list")
    public TableDataInfo list(ScheduleTask scheduleTask)
    {
        startPage();
        List<ScheduleTask> list = scheduleTaskService.selectScheduleTaskList(scheduleTask);
        return getDataTable(list);
    }

    /**
     * 导出任务定时执行列表
     */
    // @PreAuthorize("@ss.hasPermi('system:task:export')")
    @Log(title = "任务定时执行", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ScheduleTask scheduleTask)
    {
        List<ScheduleTask> list = scheduleTaskService.selectScheduleTaskList(scheduleTask);
        ExcelUtil<ScheduleTask> util = new ExcelUtil<ScheduleTask>(ScheduleTask.class);
        util.exportExcel(response, list, "任务定时执行数据");
    }

    /**
     * 获取任务定时执行详细信息
     */
    // @PreAuthorize("@ss.hasPermi('system:task:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(scheduleTaskService.selectScheduleTaskById(id));
    }

    /**
     * 新增任务定时执行
     */
    // @PreAuthorize("@ss.hasPermi('system:task:add')")
    @Log(title = "任务定时执行", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ScheduleTask scheduleTask)
    {
        return toAjax(scheduleTaskService.insertScheduleTask(scheduleTask));
    }

    /**
     * 修改任务定时执行
     */
    // @PreAuthorize("@ss.hasPermi('system:task:edit')")
    @Log(title = "任务定时执行", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ScheduleTask scheduleTask)
    {
        return toAjax(scheduleTaskService.updateScheduleTask(scheduleTask));
    }

    /**
     * 删除任务定时执行
     */
    // @PreAuthorize("@ss.hasPermi('system:task:remove')")
    @Log(title = "任务定时执行", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(scheduleTaskService.deleteScheduleTaskByIds(ids));
    }
}
